#
# spec file for package makeself
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2011-2017 Malcolm J Lewis <malcolmlewis@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           makeself
Version:        2.5.0
Release:        1.4
Summary:        Make self-extractable archives on Unix
License:        GPL-2.0-or-later
Group:          Productivity/Archiving/Compression
URL:            https://makeself.io/
Source0:        https://github.com/megastep/makeself/archive/release-%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}.rpmlintrc
BuildArch:      noarch

%description
Small shell script that generates a self-extractable tar.gz archive from a
directory. The resulting file appears as a shell script (many of those
have a .run suffix), and can be launched as is. The archive will then
uncompress itself to a temporary directory and an optional arbitrary
command will be executed (for example an installation script).

This is pretty similar to archives generated with WinZip Self-Extractor in
the Windows world. Makeself archives also include checksums for integrity
self-validation (CRC and/or MD5 checksums).

%prep
%setup -q -n %{name}-release-%{version}

%build

%install
install -Dpm 0755 makeself.sh  \
  %{buildroot}%{_bindir}/makeself
ln -s %{_bindir}/makeself %{buildroot}%{_bindir}/makeself.sh
install -Dpm 0755 makeself-header.sh  \
  %{buildroot}%{_bindir}/makeself-header.sh
install -Dpm 0644 makeself.1 \
  %{buildroot}%{_mandir}/man1/makeself.1

%files
%license COPYING
%doc README.md
%{_bindir}/makeself-header.sh
%{_bindir}/makeself.sh
%{_bindir}/makeself
%{_mandir}/man1/makeself.1%{?ext_man}

%changelog
* Tue May  2 2023 Dirk Müller <dmueller@suse.com>
- update to 2.5.0:
  * Improved support for minimal Linux distributions such as
    Alpine
  * Added bzip3 compression support
  * Increased control over GPG signing via the GPG extra
    parameters
* Sat Jul 10 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 2.4.5
  * Fix some issues with the compatibility of the archives
  * Reversing the previous generation of strictly POSIX tar archives.
  * Fix possible incompatibilities with the default ustar TAR format
  * Introducing a new --tar-format option when creating the format
* Sat Jan 30 2021 Dirk Müller <dmueller@suse.com>
- update to 2.4.3:
  * includes a number of bug fixes.
  * POSIX tar archive format is now explicitly set to increase compatibility
    between GNU and BSD variants of the command.
* Tue Jun 16 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 2.4.2:
  * New --cleanup and --cleanup-args arguments for cleanup scripts;
  * Added threading support for supported compressors
  * Now supports zstd compression.
- Changes for version 2.4.0:
  * Added new --sha256 argument to use a SHA256 checksum to verify
    the integrity of archives. The shasum or sha256sum commands
    need to be available on the targeted systems.
  * Fixes for extracting to directories containing spaces.
  * OpenSSL improvements.
  * Base64 decoding support on macOS.
  * Various documentation updates.
* Wed Nov 29 2017 plinnell@opensuse.org
- Adjust source URL for factory service run to fix factory-auto
* Sun Nov 26 2017 malcolmlewis@opensuse.org
- Fix source URL for factory service run.
* Sun Nov 26 2017 malcolmlewis@opensuse.org
- Update to version 2.3.1:
  * Various compatibility improvements.
  * New unit tests for Travis CI.
  * New --tar-extra, --untar-extra, --gpg-extra and
  - -gpg-asymmetric-encrypt-sign options.
- Changes from version 2.3.0:
  * Support for archive encryption via GPG or OpenSSL.
  * Added LZO and LZ4 compression support.
  * Options to set the packaging date and stop the umask from
    being overriden.
  * Optionally ignore check for available disk space when
    extracting.
  * New option to check for root permissions before extracting.
- Spec file tidy up.
* Mon Mar 24 2014 speilicke@suse.com
- Most software (such as Virtualbox) expects 'makeself', not makeself.sh.
  Rename and provide a compat symlink
* Sun Apr 14 2013 idonmez@suse.com
- Update to version 2.2.0
  * Adds many fixes and contributions from Github users
  * An option to give an additional argument to tar
* Mon Jul 11 2011 malcolmlewis@opensuse.org
- Update spec file License field from GPLv2+ to GPL-2.0+ to
  conform with spdx.org identifier.
- Fix error in rpmlitrc file.
* Mon Jul 11 2011 mrdocs@opensuse.org
- spec file tweaks.
- convert changelog to  .changes file.
* Tue Mar 23 2010 Malcolm J Lewis <coyoteuser@gmail.com> - 2.1.5
- initial OBS build.
